SharedRef

Struct SharedRef 

pub struct SharedRef<T>(/* private fields */)
where
    T: Shared;
Wrapper around a C++ shared_ptr. The shared_ptr is assumed to contain a value and may not be null.

Implementations

Source

impl<T> SharedRef<T>
where T: Shared,

pub fn assert_use_count_eq(&self, expected: usize)

Asserts that the number of references to the shared inner value is equal to the expected count.

This function relies on the C++ method std::shared_ptr::use_count(), which usually performs a relaxed load. This function will repeatedly call use_count() until it returns the expected value, for up to one second. Therefore it should probably not be used in performance critical code.